# dypylib (DY python libraries)

Collection of Python scripts to parse bioinformatics files

Copyright (C) 2020 You Duan

**Contact**

yduan94@ihb.ac.cn, duanyou@outlook.com

**Prerequisites**

**Introduction**

